==> qmmp-0.4.1.tar.bz2: qmmp-0.4.1/src/plugins/Output/alsa/translations/alsa_plugin_cs.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.0" language="cs">
<context>
    <name>OutputALSAFactory</name>
    <message>
        <location filename="../outputalsafactory.cpp" line="31"/>
        <source>ALSA Plugin</source>
        <translation>Modul ALSA</translation>
    </message>
    <message>
        <location filename="../outputalsafactory.cpp" line="56"/>
        <source>About ALSA Output Plugin</source>
        <translation>O modulu ALSA</translation>
    </message>
    <message>
        <location filename="../outputalsafactory.cpp" line="57"/>
        <source>Qmmp ALSA Output Plugin</source>
        <translation>Výstupní modul Qmmp ALSA</translation>
    </message>
    <message>
        <location filename="../outputalsafactory.cpp" line="58"/>
        <source>Writen by: Ilya Kotov &lt;forkotov02@hotmail.ru&gt;</source>
        <translation>Autor: Ilja Kotov &lt;forkotov02@hotmail.ru&gt;</translation>
    </message>
</context>
<context>
    <name>SettingsDialog</name>
    <message>
        <location filename="../settingsdialog.ui" line="14"/>
        <source>ALSA Plugin Settings</source>
        <translation>Nastavení pluginu ALSA</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="33"/>
        <source>Device Settings</source>
        <translation>Nastavení zařízení</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="45"/>
        <source>Audio device</source>
        <translation>Zvukové zařízení</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="57"/>
        <source>Mixer</source>
        <translation>Mixér</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="72"/>
        <source>Mixer card:</source>
        <translation>Zvuková karta:</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="82"/>
        <source>Mixer device:</source>
        <translation>Ovládání hlasitosti:</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="99"/>
        <source>Advanced Settings</source>
        <translation>Pokročilá nastavení</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="111"/>
        <source>Soundcard</source>
        <translation>Zvuková karta</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="117"/>
        <source>Buffer time (ms):</source>
        <translation>Velikost bufferu (ms):</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="153"/>
        <source>Period time (ms):</source>
        <translation>Délka periody (ms):</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="189"/>
        <source>Use mmap access</source>
        <translation>Použít mmap</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="209"/>
        <source>Use snd_pcm_pause function</source>
        <translation>Použít funkci snd_pcm_pause</translation>
    </message>
</context>
</TS>

==> qmmp-0.4.5.tar.bz2: qmmp-0.4.5/src/plugins/Output/alsa/translations/alsa_plugin_cs.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.0" language="cs">
<context>
    <name>OutputALSAFactory</name>
    <message>
        <location filename="../outputalsafactory.cpp" line="31"/>
        <source>ALSA Plugin</source>
        <translation>Modul ALSA</translation>
    </message>
    <message>
        <location filename="../outputalsafactory.cpp" line="56"/>
        <source>About ALSA Output Plugin</source>
        <translation>O modulu ALSA</translation>
    </message>
    <message>
        <location filename="../outputalsafactory.cpp" line="57"/>
        <source>Qmmp ALSA Output Plugin</source>
        <translation>Výstupní modul Qmmp ALSA</translation>
    </message>
    <message>
        <location filename="../outputalsafactory.cpp" line="58"/>
        <source>Written by: Ilya Kotov &lt;forkotov02@hotmail.ru&gt;</source>
        <translation>Autor: Ilja Kotov &lt;forkotov02@hotmail.ru&gt;</translation>
    </message>
</context>
<context>
    <name>SettingsDialog</name>
    <message>
        <location filename="../settingsdialog.ui" line="14"/>
        <source>ALSA Plugin Settings</source>
        <translation>Nastavení pluginu ALSA</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="33"/>
        <source>Device Settings</source>
        <translation>Nastavení zařízení</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="45"/>
        <source>Audio device</source>
        <translation>Zvukové zařízení</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="57"/>
        <source>Mixer</source>
        <translation>Mixér</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="72"/>
        <source>Mixer card:</source>
        <translation>Zvuková karta:</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="82"/>
        <source>Mixer device:</source>
        <translation>Ovládání hlasitosti:</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="99"/>
        <source>Advanced Settings</source>
        <translation>Pokročilá nastavení</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="111"/>
        <source>Soundcard</source>
        <translation>Zvuková karta</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="117"/>
        <source>Buffer time (ms):</source>
        <translation>Velikost bufferu (ms):</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="153"/>
        <source>Period time (ms):</source>
        <translation>Délka periody (ms):</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="189"/>
        <source>Use mmap access</source>
        <translation>Použít mmap</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="209"/>
        <source>Use snd_pcm_pause function</source>
        <translation>Použít funkci snd_pcm_pause</translation>
    </message>
</context>
</TS>
